#
# spec file for package qt6-languageserver
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.8.1
%define short_version 6.8
%define short_name qtlanguageserver
%define tar_name qtlanguageserver-everywhere-src
%define tar_suffix %{nil}
#
Name:           qt6-languageserver
Version:        6.8.1
Release:        2.1
Summary:        Implementation of the Language Server Protocol
License:        GPL-2.0-only OR LGPL-3.0-only OR GPL-3.0-only
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
BuildRequires:  qt6-core-private-devel
BuildRequires:  cmake(Qt6Concurrent) = %{real_version}
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6Network) = %{real_version}

%description
Qt Language Server implements the Language Server Protocol specification and
the JsonRpc 2.0 protocol.

### Static libraries ###

%package -n qt6-languageserver-devel-static
Summary:        LSP implementation for Qt6
Provides:       qt6-languageserver-private-devel = %{version}
Obsoletes:      qt6-languageserver-private-devel < %{version}
Requires:       cmake(Qt6JsonRpcPrivate) = %{real_version}
Obsoletes:      libQt6LanguageServer6 < 6.8.1

%description -n qt6-languageserver-devel-static
The Qt 6 LanguageServer library implements the Language Server Protocol (LSP)
specification.
This library does not have any ABI or API guarantees.

%package -n qt6-jsonrpc-devel-static
Summary:        JsonRpc 2.0 protocol implementation
Provides:       qt6-jsonrpc-private-devel = %{version}
Obsoletes:      qt6-jsonrpc-private-devel < %{version}
Obsoletes:      libQt6JsonRpc6 < 6.8.1

%description -n qt6-jsonrpc-devel-static
JsonRpc 2.0 protocol implementation for Qt6.
This library does not have any ABI or API guarantees.

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects

%cmake_qt6 \
  -DQT_GENERATE_SBOM:BOOL=FALSE

%{qt6_build}

%install
%{qt6_install}

%files -n qt6-languageserver-devel-static
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtLanguageServerTestsConfig.cmake
%{_qt6_cmakedir}/Qt6LanguageServerPrivate/
%{_qt6_descriptionsdir}/LanguageServerPrivate.json
%{_qt6_includedir}/QtLanguageServer/
%{_qt6_libdir}/libQt6LanguageServer.a
%{_qt6_libdir}/libQt6LanguageServer.prl
%{_qt6_metatypesdir}/qt6languageserverprivate_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_languageserver_private.pri

%files -n qt6-jsonrpc-devel-static
%license LICENSES/*
%{_qt6_cmakedir}/Qt6JsonRpcPrivate/
%{_qt6_descriptionsdir}/JsonRpcPrivate.json
%{_qt6_includedir}/QtJsonRpc/
%{_qt6_libdir}/libQt6JsonRpc.a
%{_qt6_libdir}/libQt6JsonRpc.prl
%{_qt6_metatypesdir}/qt6jsonrpcprivate_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_jsonrpc_private.pri

%changelog
* Wed Jan 22 2025 Antonio Larrosa <alarrosa@suse.com>
- Fix license.
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.1:
  * https://www.qt.io/blog/qt-6.8.1-released
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0:
  * https://www.qt.io/blog/qt-6.8-released
* Sat Sep 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.3
  * https://www.qt.io/blog/qt-6.7.3-released
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 Christophe Marin <christophe@krop.fr>
- Update subpackages requirements
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Feb 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Init qt6-languageserver.
